<?php

namespace Litecms\Fakeentries\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Fakeentries\Models\Fakeentries;

class FakeentriesPolicy
{

    /**
     * Determine if the given user can view the fakeentries.
     *
     * @param UserPolicy $user
     * @param Fakeentries $fakeentries
     *
     * @return bool
     */
    public function view(UserPolicy $user, Fakeentries $fakeentries)
    {
        if ($user->canDo('fakeentries.fakeentries.view') && $user->isAdmin()) {
            return true;
        }

        return $fakeentries->user_id == user_id() && $fakeentries->user_type == user_type();
    }

    /**
     * Determine if the given user can create a fakeentries.
     *
     * @param UserPolicy $user
     * @param Fakeentries $fakeentries
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('fakeentries.fakeentries.create');
    }

    /**
     * Determine if the given user can update the given fakeentries.
     *
     * @param UserPolicy $user
     * @param Fakeentries $fakeentries
     *
     * @return bool
     */
    public function update(UserPolicy $user, Fakeentries $fakeentries)
    {
        if ($user->canDo('fakeentries.fakeentries.edit') && $user->isAdmin()) {
            return true;
        }

        return $fakeentries->user_id == user_id() && $fakeentries->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given fakeentries.
     *
     * @param UserPolicy $user
     * @param Fakeentries $fakeentries
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Fakeentries $fakeentries)
    {
        return $fakeentries->user_id == user_id() && $fakeentries->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given fakeentries.
     *
     * @param UserPolicy $user
     * @param Fakeentries $fakeentries
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Fakeentries $fakeentries)
    {
        if ($user->canDo('fakeentries.fakeentries.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given fakeentries.
     *
     * @param UserPolicy $user
     * @param Fakeentries $fakeentries
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Fakeentries $fakeentries)
    {
        if ($user->canDo('fakeentries.fakeentries.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
